@@ -5,5 +5,6 @@ from .errors import TelePayError  # noqa: F401
 from .models.account import Account  # noqa: F401
 from .models.assets import Assets  # noqa: F401
 from .models.invoice import Invoice  # noqa: F401
-from .models.wallets import Wallets  # noqa: F401
+from .models.wallets import Wallet, Wallets  # noqa: F401
+from .models.webhooks import Webhook, Webhooks  # noqa: F401
 from .webhooks import TelePayWebhookListener  # noqa: F401
